/// <reference types="node" />
import { ModuleMocker } from 'jest-mock';
import { JestFakeTimers } from '@jest/fake-timers';
import { JestEnvironment, EnvironmentContext } from '@jest/environment';
import { Script } from 'vm';
import { Global, Config } from '@jest/types';
/**
 * Happy DOM Jest Environment.
 */
export default class HappyDOMEnvironment implements JestEnvironment {
    fakeTimers: JestFakeTimers<number>;
    global: Global.Global;
    moduleMocker: ModuleMocker;
    /**
     * Constructor.
     *
     * @param {Config} config Jest config.
     * @param {EnvironmentContext} options Options.
     */
    constructor(config: Config.ProjectConfig, options?: EnvironmentContext);
    /**
     * Setup.
     *
     * @return {Promise<void>} Promise.
     */
    setup(): Promise<void>;
    /**
     * Teardown.
     *
     * @return {Promise<void>} Promise.
     */
    teardown(): Promise<void>;
    /**
     * Runs a script.
     *
     * @param {Script} script Script.
     * @returns {any} Result.
     */
    runScript(script: Script): null;
    /**
     * Creates a context.
     *
     * @return {VM.Context} Context.
     */
    private createContext;
}
