"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var vm_1 = __importDefault(require("vm"));
var jest_util_1 = __importDefault(require("jest-util"));
var jest_mock_1 = require("jest-mock");
var fake_timers_1 = require("@jest/fake-timers");
var happy_dom_1 = require("happy-dom");
/**
 * Happy DOM Jest Environment.
 */
var HappyDOMEnvironment = /** @class */ (function () {
    /**
     * Constructor.
     *
     * @param {Config} config Jest config.
     * @param {EnvironmentContext} options Options.
     */
    function HappyDOMEnvironment(config, options) {
        if (options === void 0) { options = {}; }
        this.fakeTimers = null;
        this.global = this.createContext();
        this.moduleMocker = new jest_mock_1.ModuleMocker(this.global);
        var global = this.global;
        var timerConfig = {
            idToRef: function (id) { return id; },
            refToId: function (ref) { return ref; }
        };
        // Node's error-message stack size is limited at 10, but it's pretty useful
        // to see more than that when a test fails.
        global.Error.stackTraceLimit = 100;
        // Removes fetch for security reasons and it should be mocked anyway
        delete this.global.fetch;
        delete this.global.window.fetch;
        jest_util_1.default.installCommonGlobals(this.global, config.globals);
        if (options.console) {
            global.console = options.console;
            global.window.console = options.console;
        }
        this.fakeTimers = new fake_timers_1.JestFakeTimers({
            config: config,
            global: global,
            moduleMocker: this.moduleMocker,
            timerConfig: timerConfig
        });
    }
    /**
     * Setup.
     *
     * @return {Promise<void>} Promise.
     */
    HappyDOMEnvironment.prototype.setup = function () {
        return Promise.resolve();
    };
    /**
     * Teardown.
     *
     * @return {Promise<void>} Promise.
     */
    HappyDOMEnvironment.prototype.teardown = function () {
        this.fakeTimers.dispose();
        this.global.window.dispose();
        this.global = null;
        this.moduleMocker = null;
        this.fakeTimers = null;
        return Promise.resolve();
    };
    /**
     * Runs a script.
     *
     * @param {Script} script Script.
     * @returns {any} Result.
     */
    HappyDOMEnvironment.prototype.runScript = function (script) {
        return script.runInContext(this.global);
    };
    /**
     * Creates a context.
     *
     * @return {VM.Context} Context.
     */
    HappyDOMEnvironment.prototype.createContext = function () {
        return vm_1.default.createContext(new happy_dom_1.AsyncWindow());
    };
    return HappyDOMEnvironment;
}());
exports.default = HappyDOMEnvironment;
//# sourceMappingURL=index.js.map